<?php
/**
 * OMag functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package OMag
 */

if ( ! function_exists( 'omag_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function omag_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on OMag, use a find and replace
		 * to change 'omag' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'omag', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'omag' ),
			'top-nav' => esc_html__( 'Top Navigation', 'omag' ),
			'connect-socially' => esc_html__( 'Connect Socially', 'omag' ),
			'footer' => esc_html__( 'Footer', 'omag' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'omag_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'omag_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function omag_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'omag_content_width', 640 );
}
add_action( 'after_setup_theme', 'omag_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function omag_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'omag' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'omag' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<div class="widget-title"><h3><span>',
		'after_title'   => '</span></h3></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Home Page Widget Area', 'omag' ),
		'id'            => 'omag-home-page-widget-area',
		'description'   => esc_html__( 'Add widgets here to appear in Home Page Widget Area.', 'omag' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s site-content">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="article-title"><h3><span>',
		'after_title'   => '</span></h3></div>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer: One', 'omag' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<div class="widget-title"><h3><span>',
		'after_title'   => '</span></h3></div>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer: Two', 'omag' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<div class="widget-title"><h3><span>',
		'after_title'   => '</span></h3></div>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer: Three', 'omag' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<div class="widget-title"><h3><span>',
		'after_title'   => '</span></h3></div>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Header Advertisement', 'omag' ),
		'id'            => 'advertisement-1',
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h2 class="advertisement-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'omag_widgets_init' );


/**
 * Register Google fonts
 */

if ( ! function_exists( 'omag_fonts_url' ) ) {
	/**
	 *
	 * @return string Google fonts URL for the theme.
	 */
	function omag_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		/* translators: If there are characters in your language that are not supported by Catamaran, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Catamaran', 'omag' ) ) {
			$fonts[] = 'Catamaran:400,500,600,700';
		}

		/* translators: If there are characters in your language that are not supported by Titillium Web, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Titillium Web', 'omag' ) ) {
			$fonts[] = 'Titillium Web:400,600,700';
		}		

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		return $fonts_url;
	}
}

/**
 * Enqueue scripts and styles.
 */
function omag_scripts() {

	$theme_options = omag_theme_options();

	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css' );

	wp_enqueue_style( 'fontawesome-all', get_template_directory_uri() . '/assets/css/fontawesome-all.css' );

	wp_enqueue_style( 'omag-fonts', omag_fonts_url() );

	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css' );

	wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.css' );

	wp_enqueue_style( 'owl-theme-default', get_template_directory_uri() . '/assets/css/owl.theme.default.css' );

	wp_enqueue_style( 'meanmenu', get_template_directory_uri() . '/assets/css/meanmenu.css' );

	wp_enqueue_style( 'omag-style', get_stylesheet_uri() );

	wp_enqueue_style( 'omag-media', get_template_directory_uri() . '/assets/css/media.css' );

	wp_enqueue_script( 'bootstrap-bundle', get_template_directory_uri() . '/assets/js/bootstrap.bundle.js', array('jquery'), '4.1.0', true );

	wp_enqueue_script( 'fontawesome-all', get_template_directory_uri() . '/assets/js/fontawesome-all.js', array('jquery'), '5.0.8', true );

	wp_enqueue_script( 'owl-carousel-min', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array('jquery'), '2.2.1', true );

	wp_enqueue_script( 'owl-animate', get_template_directory_uri() . '/assets/js/owl.animate.js', array('jquery'), '2.1.0', true );

	wp_enqueue_script( 'meanmenu', get_template_directory_uri() . '/assets/js/jquery.meanmenu.js', array('jquery'), '2.0.7', true );

	if( 1 === $theme_options['sticky_header'] ){
		wp_enqueue_script( 'omag-sticky-header', get_template_directory_uri() . '/assets/js/sticky.header.js', array('jquery'), '1.0.0', true );
	}

	if( 1 === $theme_options['enable_top_header'] && 1 === $theme_options['enable_date'] ){
		wp_enqueue_script( 'omag-current-date', get_template_directory_uri() . '/assets/js/current.date.js', array('jquery'), '1.0.0', true );
	}

	wp_enqueue_script( 'omag-custom', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), '1.0.0', true );

	wp_enqueue_script( 'omag-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'omag-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'omag_scripts' );

/**
 * Load OMag Functions.
 */
require get_template_directory() . '/inc/init-functions.php';
